import sys
from .hruid import Generator


def main():
    print("Welcome to the HRUID library - you are in command line mode.")
    print("Available commands: generate\n")

    if len(sys.argv) == 2:
        cmd = sys.argv[1]
        if cmd == "generate":
            print(Generator().random())

    else:
        print("Incorrect usage of CLI mode.")



nouns = [
    "cats",
    "dogs",
    "elephants",
    "mice",
    "snakes",
    "sheep",
    "cows",
    "flies",
    "lions",
    "dragons",
    "slugs",
    "eagles",
    "frogs",
    "parrots",
    "alligators",
    "sharks",
    "monkeys",
    "tigers",
    "moles",
    "badgers",
    "snails",
    "chickens",
    "rooster",
    "koalas",
    "kangaroos",
    "turtles",
    "iguanas",
    "antelopes",
    "springboks",
    "armadillos",
    "foxes",
    "zebras",
    "impalas",
    "llamas",
    "jaguars",
    "baboons",
    "horses",
    "porcupines",
    "pigs",
    "crocodiles",
    "bats",
    "sloths",
    "buffalo",
    "hamster",
    "wombat",
    "kittens",
    "puppies",
    "rats",
    "reindeer",
    "donkeys",
    "alpacas",
    "owls",
    "rabbits",
    "gophers",
    "cheetahs",
    "gorillas",
    "wolves",
    "beetles",
    "pandas",
    "newts",
    "beavers",
    "chimpanzees",
    "bees",
    "crows",
    "raccoons",
    "toads",
    "ferrets",
    "whales",
    "dolphins",
    "apes",
    "deer",
]




verbs = [
    "exist",
    "discharge",
    "settle",
    "disappear",
    "coincide",
    "proceed",
    "test",
    "cancel",
    "request",
    "lean",
    "enclose",
    "march",
    "compose",
    "leave",
    "breed",
    "wander",
    "win",
    "set",
    "endorse",
    "bear",
    "spare",
    "gather",
    "hire",
    "cease",
    "subject",
    "back",
    "sing",
    "float",
    "greet",
    "recall",
    "touch",
    "lose",
    "proclaim",
    "burn",
    "hunt",
    "disagree",
    "consume",
    "apply",
    "fix",
    "couple",
    "estimate",
    "conform",
    "tour",
    "weigh",
    "deposit",
    "own",
    "convince",
    "suffer",
    "end",
    "limit",
    "operate",
    "round",
    "refuse",
    "speak",
    "declare",
    "exploit",
    "become",
    "steal",
    "remove",
    "belong",
    "force",
    "impose",
    "plunge",
    "stir",
    "express",
    "cool",
    "result",
    "undermine",
    "allocate",
    "cheer",
    "use",
    "sum",
    "squeeze",
    "store",
    "induce",
    "acquire",
    "absorb",
    "cast",
    "report",
    "manipulate",
    "presume",
    "rely",
    "schedule",
    "list",
    "account",
    "identify",
    "going",
    "remind",
    "judge",
    "call",
    "maintain",
    "in",
    "risk",
    "classify",
    "split",
    "compensate",
    "realize",
    "calculate",
    "compare",
    "provide",
    "bring",
    "time",
    "range",
    "invite",
    "underline",
    "point",
    "study",
    "review",
    "obey",
    "prescribe",
    "deny",
    "reach",
    "depend",
    "arise",
    "wash",
    "edit",
    "carry",
    "transmit",
    "perform",
    "find",
    "exercise",
    "shoot",
    "satisfy",
    "strip",
    "drag",
    "wonder",
    "sound",
    "want",
]



adjectives = [
    "practical",
    "famous",
    "healthy",
    "unusual",
    "happy",
    "logical",
    "severe",
    "federal",
    "immediate",
    "responsible",
    "lucky",
    "additional",
    "suspicious",
    "intelligent",
    "strong",
    "existing",
    "careful",
    "distinct",
    "psychological",
    "desperate",
    "serious",
    "odd",
    "eastern",
    "political",
    "similar",
    "anxious",
    "legal",
    "useful",
    "tiny",
    "sudden",
    "aware",
    "interesting",
    "technical",
    "basic",
    "strict",
    "embarrassed",
    "significant",
    "aggressive",
    "nervous",
    "traditional",
    "mad",
    "typical",
    "medical",
    "recent",
    "various",
    "unable",
    "electronic",
    "cultural",
    "administrative",
    "sorry",
    "competitive",
    "unhappy",
    "hungry",
    "huge",
    "difficult",
    "remarkable",
    "informal",
    "used",
    "lonely",
    "rare",
    "global",
    "expensive",
    "critical",
    "exciting",
    "southern",
    "realistic",
    "tall",
    "hot",
    "accurate",
    "environmental",
    "helpful",
    "dangerous",
    "ugly",
    "several",
    "entire",
    "willing",
    "large",
    "emotional",
    "nice",
    "conscious",
    "wooden",
    "different",
    "historical",
    "important",
    "obviously",
    "curious",
    "acceptable",
    "capable",
    "latter",
    "powerful",
    "automatic",
    "successful",
    "comprehensive",
    "angry",
    "impressive",
    "visible",
    "united",
    "efficient",
    "afraid",
    "asleep",
    "strange",
    "actual",
    "consistent",
    "numerous",
    "confident",
    "available",
    "civil",
    "popular",
    "dramatic",
    "scared",
    "able",
    "impossible",
    "inner",
    "known",
    "boring",
    "old",
    "unlikely",
    "mental",
    "relevant",
    "substantial",
    "foreign",
    "every",
    "suitable",
    "poor",
    "pleasant",
    "cute",
    "weak",
    "wonderful",
]




adverbs = [
    "quietly",
    "dutifully",
    "carefully",
    "crossly",
    "unethically",
    "helplessly",
    "lightly",
    "only",
    "intently",
    "angrily",
    "curiously",
    "evenly",
    "almost",
    "politely",
    "sadly",
    "mockingly",
    "unbearably",
    "loftily",
    "elegantly",
    "majestically",
    "quickly",
    "excitedly",
    "tediously",
    "upright",
    "needily",
    "questionably",
    "instantly",
    "uselessly",
    "helpfully",
    "warmly",
    "confidently",
    "virtually",
    "briskly",
    "brightly",
    "bleakly",
    "neatly",
    "hopelessly",
    "wrongly",
    "somewhat",
    "slightly",
    "always",
    "valiantly",
    "deftly",
    "eagerly",
    "unexpectedly",
    "bashfully",
    "vastly",
    "verbally",
    "justly",
    "cautiously",
    "sharply",
    "hastily",
    "rarely",
    "oddly",
    "utterly",
    "madly",
    "ultimately",
    "deeply",
    "selfishly",
    "fully",
    "repeatedly",
    "noisily",
    "crazily",
    "originally",
]




import random
from .adjectives import adjectives
from .nouns import nouns
from .verbs import verbs
from .adverbs import adverbs


def random_number():
    return str(random.randint(2, 33))


def random_adjective():
    return random.choice(adjectives)


def random_noun():
    return random.choice(nouns)


def random_verb():
    return random.choice(verbs)


def random_adverb():
    return random.choice(adverbs)


class Generator:
    def __init__(
        self,
        delimeter="-",
        use_number=True,
        use_adjective=True,
        use_noun=True,
        use_verb=True,
        use_adverb=True,
    ):
        self.delimeter = delimeter
        self.use_number = use_number
        self.use_adjective = use_adjective
        self.use_noun = use_noun
        self.use_verb = use_verb
        self.use_adverb = use_adverb

    def random(self):
        phrase_items = []
        if self.use_number:
            phrase_items.append(random_number())
        if self.use_adjective:
            phrase_items.append(random_adjective())
        if self.use_noun:
            phrase_items.append(random_noun())
        if self.use_verb:
            phrase_items.append(random_verb())
        if self.use_adverb:
            phrase_items.append(random_adverb())

        return self.delimeter.join(phrase_items)



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['hruid']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['hruid = hruid.cli:main', 'tests = scripts:run_tests']}

setup_kwargs = {
    'name': 'hruid',
    'version': '0.0.2',
    'description': 'Human Readable Unique Identifiers for Python',
    'long_description': '<p  align="center">\n  <strong>HRUID</strong>\n  <br>\n  <code>Human Readable Unique Identifier for Python</code>\n  <br><br>\n  <!-- <a href="https://badge.fury.io/py/conventional-commit"><img src="https://badge.fury.io/py/conventional-commit.svg" alt="PyPI version" height="18"></a>\n  <a href="https://travis-ci.org/nebbles/gitcommit/branches"><img src="https://travis-ci.org/nebbles/gitcommit.svg?branch=master" alt="Travis CI build" height="18"></a> -->\n</p>\n\n## Usage\n\nInstall\n```\n???\n```\n\nUse\n```python\nimport hruid\n\ngenerator = hruid.Generator()\nphrase = generator.random()\nprint(phrase)\n```\n\n## Overview\n\nThis Python package implements human readable ID generation based on the [Asanablog post by Greg\nSlovacek](https://blog.asana.com/2011/09/6-sad-squid-snuggle-softly/).\n\nIn it, he describes how a unique phrase can be generated in lieu of a confusing and complex\nalphanumeric ID.\n\n> Imagine representing 32 bits of information (numbers up to 4 billion) as a sentence instead of a jumble of digits. Each sentence can have the same predictable structure, and the number will be used to choose words from a dictionary to fill in that structure—like Mad Libs.\n> \n> One possible sentence structure can be: count + adjective + plural noun + verb + adverb, e.g. “6 sad squid snuggle softly.” We can divide the bit-space of the number like so:\n> \n> - 5 bits for the count (2-33, so it is always plural)  \n> - 7 bits for the adjective (one of 128 possibilities)  \n> - 7 bits for the plural noun (one of 128 possibilities, which we made all animals just for fun)  \n> - 7 bits for the verb (one of 128 possibilities)  \n> - 6 bits for the adverb (one of 64 possibilities)  \n>\n> Now, given a dictionary containing words categorized in this way, we can generate 4 billion unique (and sometimes very memorable) sentences. In Asana, the ID used to generate the error phrase is random, so the same sentence is unlikely to occur twice.\n\n## Develop\n\nInstall dependencies\n```\npoetry install\n```\n\nRun `example.py` which does some basic things with the package\n```\npoetry run python example.py\n```\n\nRun the package in CLI mode\n```\npoetry run python -m hruid\n```\n\nTo run tests\n```\npoetry run tests\n```\n\n## License\n\n[GNU GPLv3](./LICENSE)\n',
    'author': 'nebbles',
    'author_email': None,
    'url': 'https://github.com/nebbles/hruid-python',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
